@@ -15,6 +15,8 @@ class ClockifyDatetime:
     ClockifyDatetime is always timezone aware. If initialized with a naive datetime, local time is assumed
     """
 
+    clockify_datetime_format = "%Y-%m-%dT%H:%M:%SZ"
+
     def __init__(self, datetime_in):
         """Create
 
@@ -37,12 +39,17 @@ class ClockifyDatetime:
         """This datetime as local time"""
         return self.datetime.astimezone(dateutil.tz.tzlocal())
 
+    @property
+    def clockify_datetime(self):
+        """This datetime a clockify-format string"""
+        return self.datetime_utc.strftime(self.clockify_datetime_format)
+
     @classmethod
     def init_from_string(cls, clockify_date_string):
         return cls(date_parser.parse(clockify_date_string))
 
     def __str__(self):
-        return self.datetime.isoformat()
+        return self.clockify_datetime
 
 
 class APIObject:
@@ -191,7 +198,8 @@ class Project(NamedAPIObject):
 
 
 class ProjectStub(Project):
-    """A project with only an id. This occurs when a project ID is returned by API as part of a different query"""
+    """A project with only an id. This occurs when a project ID is returned by
+    API as part of a different query"""
     def __init__(self, obj_id):
         super().__init__(obj_id=obj_id, name=None)
 
@@ -270,5 +278,28 @@ class TimeEntry(APIObject):
         return {x: y for x, y in as_dict.items() if y}  # remove items with None value
 
 
+class TimeEntryQuery:
+    """A query for the time-entries endpoint"""
+
+    def __init__(self, description: str):
+        """
+
+        Parameters
+        ----------
+        description: str
+            time entries will be filtered by description.
+
+        """
+        self.description = description
+
+    def __str__(self):
+        return f"TimeEntryQuery ('{self.to_dict()}'"
+
+    def to_dict(self):
+        """As dict that can be sent to API"""
+        as_dict = {"description": self.description}
+        return {x: y for x, y in as_dict.items() if y}  # remove items with None value
+
+
 class ObjectParseException(ClockifyClientException):
     pass
